==> CGSocialApp-1.1.10.tar.gz: CGSocialApp/action.list_checkins.php <==
<?php
#BEGIN_LICENSE
#-------------------------------------------------------------------------
# Module: CGSocialApp (c) 2011 by Robert Campbell 
#         (calguy1000@cmsmadesimple.org)
# 
#-------------------------------------------------------------------------
# CMS - CMS Made Simple is (c) 2005 by Ted Kulp (wishy@cmsmadesimple.org)
# This project's homepage is: http://www.cmsmadesimple.org
#
#-------------------------------------------------------------------------
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# However, as a special exception to the GPL, this software is distributed
# as an addon module to CMS Made Simple.  You may not use this software
# in any Non GPL version of CMS Made simple, or in any version of CMS
# Made simple that does not indicate clearly and obviously in its admin 
# section that the site was built with CMS Made simple.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
# Or read it online: http://www.gnu.org/licenses/licenses.html#GPL
#
#-------------------------------------------------------------------------
#END_LICENSE
if( !isset($gCms) ) exit;

// list checkins by location...
if( !isset($params['locationid']) )
  {
    return;
  }
$qparms = array();
$qparms['location'] = (int)$params['location'];
$qparms['limit'] = 25;
$qparms['offset'] = 0;
if( isset($params['timelimit']) )
  {
    $qparms['timelimit'] = (int)$params['timelimit'];
  }
if( isset($params['limit']) )
  {
    $qparms['limit'] = (int)$params['limit'];
  }
if( isset($params['offset']) )
  {
    $qparms['offset'] = (int)$params['offset'];
  }
if( isset($params['sortby']) )
  {
    $qparms['sortby'] = trim($params['sortby']);
  }
if( isset($params['sortorder']) )
  {
    $qparms['sortorder'] = trim($params['sortorder']);
  }

try
{
  $query = new cgsa_checkin_query($qparms);
  $rs = $query->execute();
  if( $rs )
    {
      $output = array();
      while( !$rs->EOF )
	{
	  $output[] = $rs->fields;
	  $rs->MoveNext();
	}

      if( count($output) )
	{
	  $smarty->assign('results',$output);
	}
    }
}
catch( Exception& $e )
{
}

#
# EOF
#
?>

==> CGSocialApp-1.3.1.tar.gz: CGSocialApp/action.list_checkins.php <==
<?php
#BEGIN_LICENSE
#-------------------------------------------------------------------------
# Module: CGSocialApp (c) 2011 by Robert Campbell 
#         (calguy1000@cmsmadesimple.org)
# 
#-------------------------------------------------------------------------
# CMS - CMS Made Simple is (c) 2005 by Ted Kulp (wishy@cmsmadesimple.org)
# This project's homepage is: http://www.cmsmadesimple.org
#
#-------------------------------------------------------------------------
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# However, as a special exception to the GPL, this software is distributed
# as an addon module to CMS Made Simple.  You may not use this software
# in any Non GPL version of CMS Made simple, or in any version of CMS
# Made simple that does not indicate clearly and obviously in its admin 
# section that the site was built with CMS Made simple.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
# Or read it online: http://www.gnu.org/licenses/licenses.html#GPL
#
#-------------------------------------------------------------------------
#END_LICENSE
if( !isset($gCms) ) exit;

// list checkins by location...
if( !isset($params['locationid']) ) return;
$qparms = array();
$qparms['location'] = (int)$params['location'];
$qparms['limit'] = 25;
$qparms['offset'] = 0;
if( isset($params['timelimit']) )  $qparms['timelimit'] = (int)$params['timelimit'];
if( isset($params['limit']) )  $qparms['limit'] = (int)$params['limit'];
if( isset($params['offset']) )  $qparms['offset'] = (int)$params['offset'];
if( isset($params['sortby']) )  $qparms['sortby'] = trim($params['sortby']);
if( isset($params['sortorder']) )  $qparms['sortorder'] = trim($params['sortorder']);

try {
  $query = new cgsa_checkin_query($qparms);
  $rs = $query->execute();
  if( $rs ) {
    $output = array();
    while( !$rs->EOF ) {
      $output[] = $rs->fields;
      $rs->MoveNext();
    }

    if( count($output) ) $smarty->assign('results',$output);
  }
}
catch( Exception& $e )
{
}

#
# EOF
#
?>
